@@ -186,6 +186,10 @@ install -p -m 644 $HERE/cream.png $PREFIX/share/icons/
 # cleanup old installations
 echo "Cleaning up previous versions..."
 
+# 0.40
+if [ -e "$VRT/cream/EasyHtml.vim" ]; then
+	rm -f $VRT/cream/EasyHtml.vim
+fi
 # 0.38
 if [ -d "$VRT/cream/spelldicts" ]; then
 	rm -f $VRT/cream/spelldicts/*
